@@ -23,21 +23,20 @@
     "redundant_projection",
     "RemoveRedundantBackticks",
     "ObjectPropertyName",
-    "deprecation"
+    "deprecation",
+    "detekt:all"
 )
 @file:org.gradle.api.Generated
 
-/* ktlint-disable */
-
 package org.gradle.kotlin.dsl
 
 
-           /**
-            * Kotlin extension function taking [kotlin.reflect.KClass] for [org.gradle.workers.WorkQueue.submit].
-            *
-            * @see org.gradle.workers.WorkQueue.submit
-* @since 5.6
-            */
+/**
+ * Kotlin extension function taking [kotlin.reflect.KClass] for [org.gradle.workers.WorkQueue.submit].
+ *
+ * @see org.gradle.workers.WorkQueue.submit
+ * @since 5.6
+ */
 inline fun <T : org.gradle.workers.WorkParameters> org.gradle.workers.WorkQueue.`submit`(`workActionClass`: kotlin.reflect.KClass<out org.gradle.workers.WorkAction<T>>, `parameterAction`: org.gradle.api.Action<in T>): Unit =
     `submit`(`workActionClass`.java, `parameterAction`)
 
