@@ -23,12 +23,11 @@
     "redundant_projection",
     "RemoveRedundantBackticks",
     "ObjectPropertyName",
-    "deprecation"
+    "deprecation",
+    "detekt:all"
 )
 @file:org.gradle.api.Generated
 
-/* ktlint-disable */
-
 package org.gradle.kotlin.dsl
 
 
@@ -36,6 +35,7 @@ package org.gradle.kotlin.dsl
  * Kotlin extension function taking [kotlin.reflect.KClass] for [org.gradle.api.artifacts.result.ComponentArtifactsResult.getArtifacts].
  *
  * @see org.gradle.api.artifacts.result.ComponentArtifactsResult.getArtifacts
+ * @since 2.0
  */
 inline fun org.gradle.api.artifacts.result.ComponentArtifactsResult.`getArtifacts`(`type`: kotlin.reflect.KClass<out org.gradle.api.component.Artifact>): kotlin.collections.Set<org.gradle.api.artifacts.result.ArtifactResult> =
     `getArtifacts`(`type`.java)
